==> keycloak-model-map-17.0.1-sources.jar: org/keycloak/models/map/user/MapUserConsentEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserConsentEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserConsentEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> entityFieldDelegate;
    public MapUserConsentEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGrantedClientScopesIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addGrantedClientScopesId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedClientScopesIds(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGrantedClientScopesId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastUpdatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastUpdatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserConsentEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserConsentEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserConsentEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> entityFieldDelegate;
    public MapUserConsentEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserConsentEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGrantedClientScopesIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void addGrantedClientScopesId(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedClientScopesIds(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGrantedClientScopesId(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserConsentEntityFields.GRANTED_CLIENT_SCOPES_IDS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.CREATED_DATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastUpdatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setLastUpdatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserConsentEntityFields.LAST_UPDATED_DATE, p0);
    }
}
